from setuptools import setup
setup(name='inSis',
version='1.6.2.0',
description='installation of inSis Package',
url='https://www.jaajitech.com',
author='Sivarambrahmam',
author_email='sivarambrahmam@jaajitech.com',
license='MIT',
packages=['inSis'],
zip_safe=False)